@@ -2,7 +2,7 @@ package Datahub::Factory;
 
 use Datahub::Factory::Sane;
 
-our $VERSION = '1.72';
+our $VERSION = '1.73';
 
 use Datahub::Factory::Env;
 use Datahub::Factory::Config;
@@ -124,24 +124,18 @@ sub module {
 }
 
 1;
+
 __END__
 
+=pod
+
 =head1 NAME
 
 Datahub::Factory - A conveyor belt which transports data from a data source to a data sink.
 
-=begin markdown
-
-# STATUS
-
-[![Build Status](https://travis-ci.org/thedatahub/Datahub-Factory.svg?branch=master)](https://travis-ci.org/thedatahub/Datahub-Factory)
-[![CPANTS kwalitee](https://cpants.cpanauthors.org/dist/Datahub-Factory.png)](https://cpants.cpanauthors.org/dist/Datahub-Factory)
-
-=end markdown
-
 =head1 SYNOPSIS
 
-dhconveyor \[ARGUMENTS\] \[OPTIONS\]
+dhconveyor command OPTIONS
 
 =head1 DESCRIPTION
 
@@ -157,12 +151,11 @@ Datahub::Factory is a command line conveyor belt which automates three tasks:
 
 =back
 
-Datahub::Factory fetches data from several sources as specified by the _Importer_ settings, executes a L<Catmandu::Fix> and sends it to
-a data sink, set by _Exporter_. Several importer and exporter modules are supported.
+Datahub::Factory fetches data from several sources as specified by the Importer settings, 
+executes a L<Catmandu::Fix> and sends it to a data sink, set via an Exporter. 
+Several importer and exporter modules are provided, but developers can extend the functionality with their own modules.
 
-Datahub::Factory contains Log4perl support to monitor conveyor belt operations.
-
-Note: This toolset is not a generic tool. It has been tailored towards the functional requirements of the Flemish Art Collection use case.
+Datahub::Factory contains Log4perl support.
 
 =head1 CONFIGURATION
 
@@ -174,15 +167,18 @@ All commands share the following switches:
 
 =item --log_level
 
-Set the log_level. Takes a numeric parameter. Supported levels are: 1 (WARN), 2 (INFO), 3 (DEBUG). WARN (1) is the default.
+Set the log_level. Takes a numeric parameter. Supported levels are: 1 (WARN), 
+2 (INFO), 3 (DEBUG). WARN (1) is the default.
 
 =item --log_output
 
-Selects an output for the log messages. By default, it will send them to STDERR (pass STDERR as parameter), but STDOUT (STDOUT) and a log file (logs/import_-date-.log) (STATISTICS) are also supported.
+Selects an output for the log messages. By default, it will send them to STDERR 
+(pass STDERR as parameter), but STDOUT (STDOUT) and a log file.
 
 =item --verbose
 
-Set verbosity. Invoking the command with the --verbose, -v flag will render verbose output to the terminal.
+Set verbosity. Invoking the command with the --verbose, -v flag will render 
+verbose output to the terminal.
 
 =back
 
@@ -192,19 +188,23 @@ Set verbosity. Invoking the command with the --verbose, -v flag will render verb
 
 Documentation about command line options.
 
-It is possible to provide either all importer and/or exporter options on the command line, or to create a _pipeline configuration file_ that sets those options.
-
-=head2 L<transport [OPTIONS]|https://metacpan.org/pod/Datahub::Factory::Command::transport>
+=head2 L<transport OPTIONS|https://metacpan.org/pod/Datahub::Factory::Command::transport>
 
 Fetch data from a local or remote source, convert it to an exchange format and export the data.
 
-=head1 PLUGINS
+=head2 L<transport OPTIONS|https://metacpan.org/pod/Datahub::Factory::Command::index>
 
-_Datahub::Factory_ uses a plugin-based architecture, making it easy to extend with new functionality.
+Fetch data from a local source, and push it to an enterprise search engine via a bulk API.
 
-New commands can be added by creating a Perl module that contains a `command_name.pm` file in the `lib/Datahub/Factory/Command` path. _Datahub::Factory_ uses the L<Datahub::Factory::Command> namespace and L<App::Cmd> internally.
 
-New L<Datahub::Factory::Importer>, L<Datahub::Factory::Exporter> and L<Datahub::Factory::Fixer> plugins can be added in the same way, in the lib/Datahub/Factory/Importer, lib/Datahub/Factory/Exporter or lib/Datahub/Factory/Fixer path. All plugins use the L<Datahub::Factory::Importer> L<Datahub::Factoryy::Exporter> or L<Datahub::Factory::Fixer> namespace and the namespace package as a L<Moose::Role>.
+=head1 API
+
+Datahub::Factory uses a plugin-based architecture, making it easy to extend with new functionality.
+
+New commands can be added by creating a Perl module that contains a `command_name.pm` file in the `lib/Datahub/Factory/Command` path. 
+Datahub::Factory uses the L<Datahub::Factory::Command> namespace and leverages L<App::Cmd> internally.
+
+New L<Datahub::Factory::Importer>, L<Datahub::Factory::Exporter> and L<Datahub::Factory::Fixer> plugins can be added in the same way. 
 
 =head1 AUTHORS
 
@@ -215,6 +215,7 @@ Pieter De Praetere <pieter@packed.be>
 
 This software is copyright (c) 2016 by PACKED, vzw, Vlaamse Kunstcollectie, vzw.
 
-This is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License, Version 3, June 2007.
+This is free software; you can redistribute it and/or modify it under the terms 
+of the GNU General Public License, Version 3, June 2007.
 
 =cut
